*********************************
Importing cysgp4
*********************************

Using cysgp4 in Python is as simple as::

    >>> import cysgp4

Then one can access the provided classes/functions via::

    cysgp4.<class/function_name>(...)
